@@ -1,10 +1,10 @@
 use 5.014;
-#package Thread::Queue::Any::Monitored '1.01'; # not at PAUSE or MetaCPAN :-(
+#package Thread::Queue::Any::Monitored '1.02'; # not at PAUSE or MetaCPAN :-(
 package Thread::Queue::Any::Monitored;  # please remove if no longer needed
 
 # initializations
 our @ISA= qw( Thread::Queue::Any );
-our $VERSION= '1.01';                   # please remove if no longer needed
+our $VERSION= '1.02';                   # please remove if no longer needed
 
 # be as verbose as possible
 use warnings;
@@ -61,14 +61,16 @@ sub self { $SELF } #self
 
 sub _monitor {
     my $queue= $SELF= shift;
-    threads->self->detach if !shift;
+    threads->self->detach
+      if !shift;
     my $monitor= shift;
     my $exit=    shift;
 
     # execute any pre code
     my $post= shift || sub {};
     my $pre=  shift;
-    $pre->(@_) if $pre;
+    $pre->(@_)
+      if $pre;
 
     # make sure we have the thaw hook
     state $THAW= $queue->THAW;
@@ -90,7 +92,8 @@ sub _monitor {
             my @set= @{ $THAW->($value) };
 
             # we're done by specific exit code
-            return $post->(@_) if $set[0] ~~ $exit;
+            return $post->(@_)
+              if $set[0] ~~ $exit;
 
             # continue monitoring
             $monitor->(@set);
@@ -132,7 +135,7 @@ Thread::Queue::Any::Monitored - monitor a queue for any specific content
 
 =head1 VERSION
 
-This documentation describes version 1.01.
+This documentation describes version 1.02.
 
 =head1 DESCRIPTION
 
